==> 1.0.2_20240315_release.zip: app/provider/LogicProvider.php <==
<?php

namespace app\provider;

class LogicProvider
{
    /**
     * 注册服务
     */
    public function register(){
        container()->bind([
            "L_Api_sitemaps"=>'app\logic\api\L_sitemaps',
            "L_Admin_admin"=>'app\logic\admin\L_admin',
            "L_Admin_adminMenu"=>'app\logic\admin\L_adminMenu',
            "L_Admin_setting"=>'app\logic\admin\L_setting',
            "L_Admin_article"=>'app\logic\admin\L_article',
            "L_Admin_articleType"=>'app\logic\admin\L_articleType',
            "L_Admin_module"=>'app\logic\admin\L_module',
            "L_Admin_welcome"=>'app\logic\admin\L_welcome',
            "L_Admin_news"=>'app\logic\admin\L_news',
            "L_Admin_category"=>'app\logic\admin\L_category',
            "L_Admin_plugin_status"=>'app\logic\admin\L_plugin_status',
            "L_Admin_plugin_status_user"=>'app\logic\admin\L_plugin_status_user',
            "L_Admin_plugin_record"=>'app\logic\admin\L_plugin_record',
            "L_Admin_goods"=>'app\logic\admin\L_goods',
            "L_Admin_systemUpgrade"=>'app\logic\admin\L_systemUpgrade',
        ]);

        container()->bind([
            "L_Index_adPosition"=>'app\logic\index\L_adPosition',
            "L_Api_news"=>'app\logic\api\L_news',
        ]);

        container()->bind([
            "L_Common_plugins"=>'app\logic\common\L_plugins',
            "L_Common_caches"=>'app\logic\common\L_caches',
            "L_Common_appStore"=>'app\logic\common\L_appStore',
            "L_Common_version"=>'app\logic\common\L_version',
        ]);

        container()->bind([
            "L_Api_goods"=>'app\logic\api\L_goods',
        ]);
    }

    /**
     * 服务启动
     */
    public function boot(){

    }
}

==> 1.0.20_20240718_release.zip: app/provider/LogicProvider.php <==
<?php

namespace app\provider;

class LogicProvider
{
    /**
     * 注册服务
     */
    public function register(){
        container()->bind([
            "L_Api_sitemaps"=>'app\logic\api\L_sitemaps',
            "L_Admin_admin"=>'app\logic\admin\L_admin',
            "L_Admin_adminMenu"=>'app\logic\admin\L_adminMenu',
            "L_Admin_setting"=>'app\logic\admin\L_setting',
            "L_Admin_article"=>'app\logic\admin\L_article',
            "L_Admin_articleType"=>'app\logic\admin\L_articleType',
            "L_Admin_module"=>'app\logic\admin\L_module',
            "L_Admin_welcome"=>'app\logic\admin\L_welcome',
            "L_Admin_news"=>'app\logic\admin\L_news',
            "L_Admin_category"=>'app\logic\admin\L_category',
            "L_Admin_plugin_status"=>'app\logic\admin\L_plugin_status',
            "L_Admin_plugin_status_user"=>'app\logic\admin\L_plugin_status_user',
            "L_Admin_plugin_record"=>'app\logic\admin\L_plugin_record',
            "L_Admin_goods"=>'app\logic\admin\L_goods',
            "L_Admin_systemUpgrade"=>'app\logic\admin\L_systemUpgrade',
            "L_Admin_fields"=>'app\logic\admin\L_fields',
            "L_Admin_script_install"=>'app\logic\admin\L_script_install',
            "L_Admin_cache"=>'app\logic\admin\L_cache',
        ]);

        container()->bind([
            "L_Index_adPosition"=>'app\logic\index\L_adPosition',
            "L_Api_news"=>'app\logic\api\L_news',
            "L_Api_setting"=>'app\logic\api\L_setting',
        ]);

        container()->bind([
            "L_Common_plugins"=>'app\logic\common\L_plugins',
            "L_Common_caches"=>'app\logic\common\L_caches',
            "L_Common_appStore"=>'app\logic\common\L_appStore',
            "L_Common_version"=>'app\logic\common\L_version',
        ]);

        container()->bind([
            "L_Api_goods"=>'app\logic\api\L_goods',
        ]);

        container()->bind([
            "L_table"=>'app\logic\L_table',
            "L_tool"=>'app\logic\L_tool',
        ]);
    }

    /**
     * 服务启动
     */
    public function boot(){

    }
}
